@@ -44,3 +44,7 @@ def generate_code(channel, unit, cmd_code, with_checksum=True):
 
 def finalize_code(code):
     return b"".join([STX, code.encode(), ETX])
+
+
+class BeckerConnectionError(Exception):
+    pass
\ No newline at end of file
